# -*- coding: utf-8 -*-
from __future__ import absolute_import, print_function, unicode_literals

try:
    import unittest2 as unittest
except ImportError:
    import unittest
import test
import yamlish

test_data_list = [
  {
    "name": 'Simple scalar',
    "in": 1,
    "out": """\
    --- 1
    ...
    """,
  },
  {
    "name": 'Undef',
    "in": None,
    "out": """\
    --- ~
    ...
    """,
  },
  {
    "name": 'Unprintable',
    "in": "\x01\n\t",
    "out": """\
    ---
    "\\x01\\n\\t"
    ...
    """,
  },
  {
    "name": 'Simple array',
    "in": [ 1, 2, 3 ],
    "out": """\
    ---
    - 1
    - 2
    - 3
    ...
    """,
  },
  {
    "name": 'Array, two elements, None',
    "in": [ None, None ],
    "out": """\
    ---
    - ~
    - ~
    ...
    """,
  },
  {
    "name": 'Nested array',
    "in": [ 1, 2, [ 3, 4 ], 5 ],
    "out": """\
    ---
    - 1
    - 2
    -
      - 3
      - 4
    - 5
    ...
    """,
  },
  {
    "name": 'Simple hash',
    "in": { "one": 1, "two": 2, "three": 3 },
    "out": """\
    ---
    one: 1
    three: 3
    two: 2
    ...
    """,
  },
  {
    "name": 'Nested hash',
    "in": {
      "one": 1,
      "two": 2,
      "more": { "three": 3, "four": 4 }
    },
    "out": """\
     ---
     more:
       four: 4
       three: 3
     one: 1
     two: 2
     ...
    """,
  },
  {
    "name": 'Unprintable key',
    "in": { "one": 1, "\x02": 2, "three": 3 },
    "out": """\
     ---
     "\\x02": 2
     one: 1
     three: 3
     ...
    """,
  },
  {
    "name": 'Empty key',
    "in": { '': 'empty' },
    "out": """\
     ---
      '': empty
     ...
    """,
  },
  {
    "name": 'Empty value',
    "in": { '': '' },
    "out": """\
     ---
       '': ''
     ...
    """,
  },
  {
    "name": 'Complex',
    "in": {
      'bill-to': {
        'given': 'Chris',
        'address': {
          'city': 'Royal Oak',
          'postal': 48046,
          'lines': "458 Walkman Dr.\nSuite #292\n",
          'state': 'MI'
        },
        'family': 'Dumars'
      },
      'invoice': 34843,
      'date': '2001-01-23',
      'tax': 251.42,
      'product': [
        {
          'sku': 'BL394D',
          'quantity': 4,
          'price': 450.00,
          'description': 'Basketball'
        },
        {
          'sku': 'BL4438H',
          'quantity': 1,
          'price': 2392.00,
          'description': 'Super Hoop'
        }
      ],
      'comments':
       "Late afternoon is best. Backup contact is Nancy Billsmer @ 338-4338\n",
      'total': 4443.52
    },
    "out": r"""
    ---
    bill-to:
      address:
        city: 'Royal Oak'
        lines: "458 Walkman Dr.\nSuite #292\n"
        postal: 48046
        state: MI
      family: Dumars
      given: Chris
    comments: "Late afternoon is best. Backup contact is Nancy Billsmer @ 338-4338\n"
    date: 2001-01-23
    invoice: 34843
    product:
      -
        description: Basketball
        price: 450.00
        quantity: 4
        sku: BL394D
      -
        description: 'Super Hoop'
        price: 2392.00
        quantity: 1
        sku: BL4438H
    tax: 251.42
    total: 4443.52
    ...
    """,
  },
]

class TestWriter(unittest.TestCase):  # IGNORE:C0111
    pass

test.generate_testsuite(test_data_list, TestWriter, yamlish.dump, direction=test.OUTPUT)

if __name__ == "__main__":
    unittest.main()



# -*- coding: utf-8 -*-
from __future__ import absolute_import, print_function, unicode_literals
import test
try:
    import unittest2 as unittest
except ImportError:
    import unittest
import yamlish

test_data_list = [
    {
     "name": "Input test",
     "in": r"""---
bill-to:
  address:
    city: "Royal Oak"
    lines: "458 Walkman Dr.\nSuite #292\n"
    postal: 48046
    state: MI
  family: Dumars
  given: Chris
comments: "Late afternoon is best. Backup contact is Nancy Billsmer @ 338-4338\n"
date: 2001-01-23
invoice: 34843
product:
  -
    description: Basketball
    price: 450.00
    quantity: 4
    sku: BL394D
  -
    description: "Super Hoop"
    price: 2392.00
    quantity: 1
    sku: BL4438H
tax: 251.42
total: 4443.52
...
""",
    'out': {
        'bill-to': {
          'given': 'Chris',
          'address': {
            'city': 'Royal Oak',
            'postal': 48046,
            'lines': "458 Walkman Dr.\nSuite #292\n",
            'state': 'MI'
          },
          'family': 'Dumars'
        },
        'invoice': 34843,
        'date': '2001-01-23',
        'tax': 251.42,
        'product': [
          {
            'sku': 'BL394D',
            'quantity': 4,
            'price': 450.00,
            'description': 'Basketball'
          },
          {
            'sku': 'BL4438H',
            'quantity': 1,
            'price': 2392.00,
            'description': 'Super Hoop'
          }
        ],
        'comments':
         "Late afternoon is best. Backup contact is Nancy Billsmer @ 338-4338\n",
        'total': 4443.52
        }
     }
]

class TestInput(unittest.TestCase):  # IGNORE:C0111
    pass

test.generate_testsuite(test_data_list, TestInput, yamlish.load)

if __name__ == "__main__":
    unittest.main()



# -*- coding: utf-8 -*-
"""
Test general output functionality.

Without much stress on the format itself.
"""
from __future__ import absolute_import, print_function, unicode_literals
try:
    import unittest2 as unittest
except ImportError:
    import unittest
import yamlish
import yaml
import logging
import tempfile

OUT = """---
bill-to:
  address:
    city: Royal Oak
    lines: "458 Walkman Dr.\\nSuite #292\\n"
    postal: 48046
    state: MI
  family: Dumars
  given: Chris
comments: Late afternoon is best. Backup contact is Nancy Billsmer @ 338-4338
date: 2001-01-23
invoice: 34843
product:
  -
    description: Basketball
    price: 450.00
    quantity: 4
    sku: BL394D
  -
    description: Super Hoop
    price: 2392.00
    quantity: 1
    sku: BL4438H
tax: 251.42
total: 4443.52
...
"""

IN = {
  'bill-to': {
    'given': 'Chris',
    'address': {
      'city': 'Royal Oak',
      'postal': 48046,
      'lines': "458 Walkman Dr.\nSuite #292\n",
      'state': 'MI'
    },
    'family': 'Dumars'
  },
  'invoice': 34843,
  'date': '2001-01-23',
  'tax': 251.42,
  'product': [
    {
      'sku': 'BL394D',
      'quantity': 4,
      'price': 450.00,
      'description': 'Basketball'
    },
    {
      'sku': 'BL4438H',
      'quantity': 1,
      'price': 2392.00,
      'description': 'Super Hoop'
    }
  ],
  'comments': "Late afternoon is best. Backup contact is Nancy Billsmer @ 338-4338",
  'total': 4443.52
}

class TestOuptut(unittest.TestCase):
    def setUp(self):
        """
        Transform expected list into string which we actually use.
        """
        self._expected = yaml.safe_load(OUT)


    def test_file_output(self):
        """
        Test output to a file.
        """
        outf = tempfile.TemporaryFile()
        yamlish.dump(IN, outf)
        outf.seek(0)
        got_str = outf.read()
        outf.close()
        logging.debug("got_str = %s", got_str)
        got = yaml.safe_load(got_str)
        self.assertEqual(got, self._expected, "Result matches")


    def test_string_output(self):
        """
        Test output to a string.
        """
        got_str = yamlish.dumps(IN)
        got = yaml.load(got_str)
        self.assertEqual(got, self._expected, "Result matches")

if __name__ == "__main__":
    unittest.main()



# -*- coding: utf-8 -*-
from __future__ import absolute_import, print_function, unicode_literals
try:
    import unittest2 as unittest
except ImportError:
    import unittest

class TestBasics(unittest.TestCase):
    def test_import(self):
        import yamlish
        self.assertTrue(yamlish.__version__,
            "Testing import of yamlish, version %s." % yamlish.__version__)

if __name__ == "__main__":
    unittest.main()



# -*- coding: utf-8 -*-
#Copyright (C) 2012 Red Hat, Inc.
#
#Permission is hereby granted, free of charge, to any person obtaining a copy of
#this software and associated documentation files (the "Software"), to deal in
#the Software without restriction, including without limitation the rights to
#use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
#of the Software, and to permit persons to whom the Software is furnished to do
#so, subject to the following conditions:
#
#The above copyright notice and this permission notice shall be included in all
#copies or substantial portions of the Software.
#
#THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#SOFTWARE.
"""
Easy YAML serialisation compatible with TAP format.

Port of `Data::YAML Perl module <https://github.com/AndyA/Data--YAML>`,
satisfying all its tests, intended to be used for support of
`TAP <http://testanything.org/>` data format. Port of the original
documentation follows.

The syntax accepted by this module is a subset of `YAML <http://yaml.org>`.

===========
YAML syntax
===========

Although YAML appears to be a simple language, the entire YAML
specification is huge. This module implements a small subset of the
complete syntax trading completeness for compactness and simplicity.
This restricted syntax is known (to me at least) as 'YAMLish'.

These examples demonstrates the full range of supported syntax.

All YAML documents must begin with '---' and end with a line
containing '...'.

::

    --- Simple scalar
    ...

Unprintable characters are represented using standard escapes in double
quoted strings.

::

    --- "\\t\\x01\\x02\\n"
    ...

Array and hashes are represented thusly

::

    ---
      - "This"
      - "is"
      - "an"
      - "array"
    ...

    ---
      This: is
      a: hash
    ...

Structures may nest arbitrarily

::

    ---
      -
        name: 'Hash one'
        value: 1
      -
        name: 'Hash two'
        value: 2
    ...

Undef is a tilde

::

    --- ~
    ...

====
Uses
====

This module may be used any time you need to freeze and thaw Python
data structures into a human readable format. The output from
`yamlish.dump()` should be readable by any YAML parser.

The original Perl module was originally written to allow machine-readable
diagnostic information to be passed from test scripts to
the Perl module `TAP::Harness`. That means that if you're writing
a testing system that needs to output TAP version 13 or later
syntax you might find this module useful.

Read more about TAP and YAMLish on `<http://testanything.org/wiki>`

"""
from __future__ import absolute_import, print_function, unicode_literals
import logging
import yaml

__docformat__ = 'reStructuredText'
__version__ = "0.10"
__author__ = u"Matěj Cepl <mcepl_at_redhat_dot_com>"

class _YamlishLoader(yaml.loader.SafeLoader):
    """
    Remove a datetime resolving.

    YAMLish returns unchanged string.
    """
    def __init__(self, stream):
        yaml.loader.SafeLoader.__init__(self, stream)

    @classmethod
    def remove_implicit_resolver(cls, tag):
        """
        Remove an implicit resolver from a Loader class identified by its tag.
        """
        if not 'yaml_implicit_resolvers' in cls.__dict__:
            cls.yaml_implicit_resolvers = cls.yaml_implicit_resolvers.copy()
        for key in cls.yaml_implicit_resolvers:
            resolvers_set = cls.yaml_implicit_resolvers[key]
            for idx in range(len(resolvers_set)):
                if resolvers_set[idx][0] == tag:
                    del resolvers_set[idx]
            if len(resolvers_set) == 0:
                del cls.yaml_implicit_resolvers[key]

_YamlishLoader.remove_implicit_resolver(u'tag:yaml.org,2002:timestamp')

class _YamlishDumper(yaml.dumper.SafeDumper):
    pass

def str_representer_compact_multiline(dumper, data):
    style = None
    if '\n' in data:
        style = '|'
    if isinstance(data, str):
        data = data.decode('utf-8') # assumes all your strings are UTF-8 encoded
    tag = u'tag:yaml.org,2002:str'
    return dumper.represent_scalar(tag, data, style)

yaml.add_representer(str, str_representer_compact_multiline,
                     Dumper=_YamlishDumper)
yaml.add_representer(unicode, str_representer_compact_multiline,
                     Dumper=_YamlishDumper)

def load(source):
    """
    Return object loaded from a YAML document in source.

    Source is either a representation of the YAML document itself
    or any document providing an iterator (that includes file, list, and
    many others).
    """
    out = None
    logging.debug("inobj:\n%s", source)
    if isinstance(source, (str, unicode)):
        out = yaml.load(source, Loader=_YamlishLoader)
        logging.debug("out (string) = %s", out)
    elif hasattr(source, "__iter__"):
        inobj = ""
        for line in source:
            inobj += line + '\n'
        out = load(inobj)
        logging.debug("out (iter) = %s", out)
    return out

def dump(source, destination):
    """
    Store source in destination file.

    Destination is either a file object or a string with a filename.
    """
    if isinstance(destination, (str, unicode)):
        with open(destination, "w") as outf:
            dump(source, outf)
    elif hasattr(destination, "fileno"):
        yaml.dump(source, destination, encoding="utf-8",
                  default_flow_style=False, canonical=False,
                  Dumper=_YamlishDumper)
    else:
        raise NameError

def dumps(source):
    """
    Return YAMLish string from given source.
    """
    return yaml.dump(source, encoding="utf-8",
                     explicit_start=True, explicit_end=True,
                     default_flow_style=False, default_style=False,
                     canonical=False, Dumper=_YamlishDumper)



# coding: utf-8
from setuptools import setup
requires_list = [
    "PyYAML>=3.09"
]
import os.path


def read(fname):
    with open(os.path.join(os.path.dirname(__file__), fname)) as inf:
        return "\n" + inf.read().replace("\r\n", "\n")

setup(
    name='yamlish',
    version="0.11",
    description='Python implementation of YAMLish',
    author='Matěj Cepl',
    author_email='mcepl@redhat.com',
    url='http://luther.ceplovi.cz/git/?p=yamlish.git;a=summary',
    py_modules=['yamlish'],
    long_description=read("README.txt"),
    keywords=['TAP', 'YAML', 'yamlish'],
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.6",
        "Programming Language :: Python :: 2.7",
        "Development Status :: 5 - Production/Stable",
        "Environment :: Console",
        "Intended Audience :: Information Technology",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Text Processing :: Markup",
    ],
    test_suite="test",
    install_requires=requires_list
)
